Documentation
¶
Overview ¶
Package v1alpha1 contains API Schema definitions for the splunkforwarder v1alpha1 API group +kubebuilder:object:generate=true +groupName=splunkforwarder.managed.openshift.io
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( // GroupVersion is group version used to register these objects GroupVersion = schema.GroupVersion{Group: "splunkforwarder.managed.openshift.io", Version: "v1alpha1"} // SchemeBuilder is used to add go types to the GroupVersionKind scheme SchemeBuilder = &scheme.Builder{GroupVersion: GroupVersion} // AddToScheme adds the types in this group-version to the given scheme. AddToScheme = SchemeBuilder.AddToScheme )
Functions ¶
func GetOpenAPIDefinitions ¶
func GetOpenAPIDefinitions(ref common.ReferenceCallback) map[string]common.OpenAPIDefinition
Types ¶
type SplunkFilter ¶
type SplunkFilter struct {
// Name of the filter, will be prepended with "filter_".
Name string `json:"name"`
// Routing criteria regex for the filter to match on.
Filter string `json:"filter"`
}
SplunkFilter is the struct that configures Splunk Heavy Forwarder filters.
func (*SplunkFilter) DeepCopy ¶
func (in *SplunkFilter) DeepCopy() *SplunkFilter
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new SplunkFilter.
func (*SplunkFilter) DeepCopyInto ¶
func (in *SplunkFilter) DeepCopyInto(out *SplunkFilter)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type SplunkForwarder ¶
type SplunkForwarder struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec SplunkForwarderSpec `json:"spec,omitempty"`
Status SplunkForwarderStatus `json:"status,omitempty"`
}
SplunkForwarder is the Schema for the splunkforwarders API +k8s:openapi-gen=true +kubebuilder:subresource:status
func (*SplunkForwarder) DeepCopy ¶
func (in *SplunkForwarder) DeepCopy() *SplunkForwarder
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new SplunkForwarder.
func (*SplunkForwarder) DeepCopyInto ¶
func (in *SplunkForwarder) DeepCopyInto(out *SplunkForwarder)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*SplunkForwarder) DeepCopyObject ¶
func (in *SplunkForwarder) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type SplunkForwarderInputs ¶
type SplunkForwarderInputs struct {
// Required: Filepath for Splunk to monitor.
Path string `json:"path"`
// Repository for data. More info: https://docs.splunk.com/Splexicon:Index
// Optional: Defaults to "main"
Index string `json:"index,omitempty"`
// Data structure of the event. More info: https://docs.splunk.com/Splexicon:Sourcetype
// Optional: Defaults to "_json"
SourceType string `json:"sourceType,omitempty"`
// Regex to monitor certain files. Multiple regex rules may be specified separated by "|" (OR)
// Optional: Defaults to monitoring all files in the specified Path
WhiteList string `json:"whiteList,omitempty"`
// Regex to exclude certain files from monitoring. Multiple regex rules may be specified separated by "|" (OR)
// Optional: Defaults to monitoring all files in the specified Path
BlackList string `json:"blackList,omitempty"`
}
SplunkForwarderInputs is the struct that defines all the splunk inputs
func (*SplunkForwarderInputs) DeepCopy ¶
func (in *SplunkForwarderInputs) DeepCopy() *SplunkForwarderInputs
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new SplunkForwarderInputs.
func (*SplunkForwarderInputs) DeepCopyInto ¶
func (in *SplunkForwarderInputs) DeepCopyInto(out *SplunkForwarderInputs)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type SplunkForwarderList ¶
type SplunkForwarderList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []SplunkForwarder `json:"items"`
}
SplunkForwarderList contains a list of SplunkForwarder
func (*SplunkForwarderList) DeepCopy ¶
func (in *SplunkForwarderList) DeepCopy() *SplunkForwarderList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new SplunkForwarderList.
func (*SplunkForwarderList) DeepCopyInto ¶
func (in *SplunkForwarderList) DeepCopyInto(out *SplunkForwarderList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*SplunkForwarderList) DeepCopyObject ¶
func (in *SplunkForwarderList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type SplunkForwarderSpec ¶
type SplunkForwarderSpec struct {
// Adds an --accept-license flag to automatically accept the Splunk License Agreement.
// Must be true for the Red Hat provided Splunk Forwarder image.
// Optional: Defaults to false.
SplunkLicenseAccepted bool `json:"splunkLicenseAccepted,omitempty"`
// Container image path to the Splunk Forwarder
Image string `json:"image"`
// The container image tag of the Splunk Forwarder image.
// Is not used if ImageDigest is supplied.
// Optional: Defaults to latest
ImageTag string `json:"imageTag,omitempty"`
// Container image digest of the Splunk Forwarder image.
// Has precedence and is recommended over ImageTag.
// Optional: Defaults to latest
ImageDigest string `json:"imageDigest,omitempty"`
// Unique cluster name.
// Optional: Looked up on the cluster if not provided, default to openshift
ClusterID string `json:"clusterID,omitempty"`
// +listType=atomic
SplunkInputs []SplunkForwarderInputs `json:"splunkInputs"`
// Whether an additional Splunk Heavy Forwarder should be deployed.
// Optional: Defaults to false.
UseHeavyForwarder bool `json:"useHeavyForwarder,omitempty"`
// Container image path to the Splunk Heavy Forwarder image. Required when
// UseHeavyForwarder is true.
HeavyForwarderImage string `json:"heavyForwarderImage,omitempty"`
// Container image digest of the container image defined in HeavyForwarderImage.
// Optional: Defaults to latest
HeavyForwarderDigest string `json:"heavyForwarderDigest,omitempty"`
// Number of desired Splunk Heavy Forwarder pods.
// Optional: Defaults to 2
HeavyForwarderReplicas int32 `json:"heavyForwarderReplicas,omitempty"`
// Specifies the value of the NodeSelector for the Splunk Heavy Forwarder pods
// with key: "node-role.kubernetes.io"
// Optional: Defaults to an empty value.
HeavyForwarderSelector string `json:"heavyForwarderSelector,omitempty"`
// List of additional filters supplied to configure the Splunk Heavy Forwarder
// Optional: Defaults to no additional filters (no transforms.conf).
// +listType=map
// +listMapKey=name
Filters []SplunkFilter `json:"filters,omitempty"`
}
SplunkForwarderSpec defines the desired state of SplunkForwarder +k8s:openapi-gen=true
func (*SplunkForwarderSpec) DeepCopy ¶
func (in *SplunkForwarderSpec) DeepCopy() *SplunkForwarderSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new SplunkForwarderSpec.
func (*SplunkForwarderSpec) DeepCopyInto ¶
func (in *SplunkForwarderSpec) DeepCopyInto(out *SplunkForwarderSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type SplunkForwarderStatus ¶
type SplunkForwarderStatus struct {
}
SplunkForwarderStatus defines the observed state of SplunkForwarder +k8s:openapi-gen=true
func (*SplunkForwarderStatus) DeepCopy ¶
func (in *SplunkForwarderStatus) DeepCopy() *SplunkForwarderStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new SplunkForwarderStatus.
func (*SplunkForwarderStatus) DeepCopyInto ¶
func (in *SplunkForwarderStatus) DeepCopyInto(out *SplunkForwarderStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.